(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    138090,       2881]
NotebookOptionsPosition[    135293,       2791]
NotebookOutlinePosition[    135696,       2808]
CellTagsIndexPosition[    135653,       2805]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Norvaisas & Kisdi, Am. Nat. Figure 3", "Section",
 CellChangeTimes->{{3.436982201356619*^9, 3.436982210069147*^9}, {
  3.436984084614611*^9, 3.4369840906933517`*^9}, {3.5273987400235*^9, 
  3.527398762851625*^9}, {3.52739904555475*^9, 3.527399049070375*^9}, {
  3.5421003599544616`*^9, 3.542100361624628*^9}}],

Cell["\<\
This notebook produces Figure 3 based on equations (3a,b), (A3) and (A4)
Natural selection according to the Levene model (Appendix, Table 1) with \
equal selection coefficients (sd=sr=s)\
\>", "Text",
 CellChangeTimes->{{3.5421004096664324`*^9, 3.5421004404995155`*^9}, {
  3.542100712253688*^9, 3.5421008756750283`*^9}, {3.5421009408535457`*^9, 
  3.5421009471181717`*^9}, {3.542100978247285*^9, 3.542100980423502*^9}, {
  3.5421026619636393`*^9, 3.5421026667391167`*^9}, {3.542106235957367*^9, 
  3.5421062370363665`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"u1", "=", 
   RowBox[{
    RowBox[{"c", "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u2", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v1", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v2", "=", 
   RowBox[{
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alpha2crit0", "=", 
   RowBox[{"alpha1", "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"u2", "/", "u1"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alpha2crit1", "=", 
   RowBox[{"alpha1", "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"v1", "/", "v2"}], "-", "1"}], ")"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.542101266221079*^9, 3.5421012679382505`*^9}, {
  3.5421013520446606`*^9, 3.542101456521107*^9}, {3.542106361341367*^9, 
  3.542106441007367*^9}}],

Cell["\<\
d, h, r : initial genotype frequencies among zygotes
ds, hs, rs : genotype frequencies after natural selection
dnext, hnext, rnext : genotype frequencies among the zygotes of the next \
generation\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"d", "=", 
   RowBox[{
    RowBox[{"p", "^", "2"}], "+", 
    RowBox[{"F", " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "p"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "p"}], ")"}], "^", "2"}], "+", 
    RowBox[{"F", " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "p"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{"1", "-", "d", "-", "r"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ds", "=", 
   RowBox[{
    RowBox[{"c", " ", 
     RowBox[{"d", "/", 
      RowBox[{"(", 
       RowBox[{"d", "+", " ", "h", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "r"}]}], ")"}]}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}], " ", 
     RowBox[{"d", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "d"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "h"}], "+", "r"}], 
       ")"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hs", "=", 
   RowBox[{
    RowBox[{"c", " ", 
     RowBox[{"h", "/", 
      RowBox[{"(", 
       RowBox[{"d", "+", " ", "h", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "r"}]}], ")"}]}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}], " ", 
     RowBox[{"h", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "d"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "h"}], "+", "r"}], 
       ")"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rs", "=", 
   RowBox[{
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "s"}], ")"}], " ", 
     RowBox[{"r", "/", 
      RowBox[{"(", 
       RowBox[{"d", "+", "h", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "r"}]}], ")"}]}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "c"}], ")"}], " ", 
     RowBox[{"r", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "d"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}], " ", "h"}], "+", "r"}], 
       ")"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dnext", "=", 
   RowBox[{
    RowBox[{"ds", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"alpha1", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ds", "+", 
           RowBox[{"hs", "/", "2"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"ds", "+", "hs"}], ")"}]}]}], " ", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "alpha1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"ds", "+", 
          RowBox[{"hs", "/", "2"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"hs", "/", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"alpha1", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ds", "+", 
           RowBox[{"hs", "/", "2"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"ds", "+", "hs"}], ")"}]}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "alpha1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"ds", "+", 
          RowBox[{"hs", "/", "2"}]}], ")"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rnext", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"hs", "/", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"alpha1", " ", 
        RowBox[{
         RowBox[{"hs", "/", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{"ds", "+", "hs"}], ")"}]}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "alpha1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"rs", "+", 
          RowBox[{"hs", "/", "2"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"rs", " ", 
     RowBox[{"(", 
      RowBox[{"alpha2", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "alpha2"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"rs", "+", 
          RowBox[{"hs", "/", "2"}]}], ")"}]}]}], ")"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"hnext", "=", 
   RowBox[{"1", "-", "dnext", "-", "rnext"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pnext", "=", 
   RowBox[{"dnext", "+", 
    RowBox[{"hnext", "/", "2"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Fnext", "=", 
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{
      RowBox[{"hnext", "/", "2"}], "/", "pnext"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "pnext"}], ")"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4369820442106543`*^9, 3.4369821986126738`*^9}, 
   3.436982234744629*^9, {3.436982699182458*^9, 3.4369827944594593`*^9}, {
   3.4369841092900925`*^9, 3.436984130730923*^9}, {3.436984193010477*^9, 
   3.436984371767517*^9}, {3.436985223792669*^9, 3.4369852483980494`*^9}, {
   3.52739879186725*^9, 3.52739889574225*^9}, {3.527398937836*^9, 
   3.527399032961*^9}, {3.527399274164125*^9, 3.527399351445375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "[", 
   RowBox[{"p0_", ",", "F0_"}], "]"}], ":=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pnext", "\[Equal]", "p"}], ",", 
      RowBox[{"Fnext", " ", "\[Equal]", "F"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"p", ",", "p0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"F", ",", "F0"}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["Numerics: c=0.5, s=0.2 (Fig 3a)", "Subsection",
 CellChangeTimes->{{3.5275129799815454`*^9, 3.527512980642496*^9}, {
  3.527588202429216*^9, 3.5275882072060847`*^9}, {3.5421041411205406`*^9, 
  3.5421041411685452`*^9}, {3.54210483318474*^9, 3.542104835857007*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"c", ",", " ", "s"}], "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", " ", "0.2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5421014900454593`*^9, 3.5421015735248065`*^9}, {
  3.5421016059340467`*^9, 3.5421016557440276`*^9}, {3.5421025341198564`*^9, 
  3.5421025349519396`*^9}, {3.542102588170261*^9, 3.542102588587302*^9}, {
  3.542102642387682*^9, 3.542102644179861*^9}, {3.5421041437448025`*^9, 
  3.5421041438008084`*^9}}],

Cell["\<\
The fixation equilibria are unstable in the area between the lines (based on \
equations (3a,b))\
\>", "Text",
 CellChangeTimes->{{3.527415065029104*^9, 3.5274151209094563`*^9}, {
   3.5274151690987487`*^9, 3.527415217268013*^9}, {3.5274152505558786`*^9, 
   3.5274152871484957`*^9}, {3.527415368465424*^9, 3.527415370828822*^9}, {
   3.5274155031991615`*^9, 3.527415527163621*^9}, 3.5421025990253463`*^9, {
   3.542102691300573*^9, 3.5421028245048923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"alpha2", "-", "alpha2crit0"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{"alpha2", "-", "alpha2crit1"}], ")"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"alpha1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"alpha2", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", "0", "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", "White"}], "}"}]}], ",", " ", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.542102836010042*^9, 3.5421029119496355`*^9}, {
   3.542104058638293*^9, 3.5421040633507643`*^9}, 3.5421043223676634`*^9, {
   3.542106376260367*^9, 3.5421064536383667`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"resol", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "0"}], ",", 
    RowBox[{"i", "\[LessEqual]", "resol"}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "0"}], ",", 
      RowBox[{"j", "\[LessEqual]", "resol"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Fsol", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "=", 
       RowBox[{"-", "1"}]}]}], "]"}]}], "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", " ", 
     RowBox[{"i", "\[LessEqual]", "resol"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"alpha1", "=", 
       RowBox[{"i", "/", "resol"}]}], ";", " ", 
      RowBox[{"alpha2", "=", "alpha1"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"solval", "=", 
       RowBox[{"sol", "[", 
        RowBox[{"0.4", ",", "0.3"}], "]"}]}], ";", " ", 
      RowBox[{
       RowBox[{"psol", "[", 
        RowBox[{"i", ",", "i"}], "]"}], "=", 
       RowBox[{"p", " ", "/.", " ", "solval"}]}], ";", " ", 
      RowBox[{
       RowBox[{"Fsol", "[", 
        RowBox[{"i", ",", "i"}], "]"}], "=", 
       RowBox[{"F", " ", "/.", " ", "solval"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", 
          RowBox[{"Min", "[", 
           RowBox[{
            RowBox[{"resol", "-", "i"}], ",", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"u2", "/", "u1"}]}], ")"}], " ", "resol"}]}], "]"}]}], 
         ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"alpha2", "=", 
           RowBox[{"alpha1", "+", 
            RowBox[{"j", "/", "resol"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"solval", "=", 
           RowBox[{"sol", "[", 
            RowBox[{
             RowBox[{"psol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "-", "1"}]}], "]"}], ",", " ", 
             RowBox[{"Fsol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "-", "1"}]}], "]"}]}], "]"}]}], ";", 
          " ", 
          RowBox[{
           RowBox[{"psol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"p", " ", "/.", " ", "solval"}]}], ";", 
          RowBox[{
           RowBox[{"Fsol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"F", " ", "/.", " ", "solval"}]}], ";"}]}], "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", 
          RowBox[{"-", "1"}]}], ",", 
         RowBox[{"j", "\[GreaterEqual]", 
          RowBox[{"Max", "[", 
           RowBox[{
            RowBox[{"-", "i"}], ",", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"v1", "/", "v2"}], "-", "1"}], ")"}], " ", "resol"}]}],
            "]"}]}], ",", 
         RowBox[{"j", "--"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"alpha2", "=", 
           RowBox[{"alpha1", "+", 
            RowBox[{"j", "/", "resol"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"solval", "=", 
           RowBox[{"sol", "[", 
            RowBox[{
             RowBox[{"psol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "+", "1"}]}], "]"}], ",", 
             RowBox[{"Fsol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "+", "1"}]}], "]"}]}], "]"}]}], ";", 
          " ", 
          RowBox[{
           RowBox[{"psol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"p", " ", "/.", " ", "solval"}]}], ";", 
          RowBox[{
           RowBox[{"Fsol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"F", " ", "/.", " ", "solval"}]}], ";"}]}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{"alpha1", ",", "alpha2", ",", "i", ",", "j"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.527415386421243*^9, 3.5274154673676386`*^9}, {
  3.527415553821954*^9, 3.527415631713957*^9}, {3.5274156809547615`*^9, 
  3.527415759507715*^9}, {3.527416859279109*^9, 3.527416869503811*^9}, {
  3.527416902641461*^9, 3.5274169643401794`*^9}, {3.527416996276101*^9, 
  3.5274171327223005`*^9}, {3.5274171696453934`*^9, 3.527417257611883*^9}, {
  3.5274172891872864`*^9, 3.527417305000024*^9}, {3.527417335113325*^9, 
  3.527417412734939*^9}, {3.5274176767145233`*^9, 3.527417680860485*^9}, {
  3.527417895449048*^9, 3.527417936828549*^9}, {3.5274190007584047`*^9, 
  3.5274190012390957`*^9}, {3.527419306788454*^9, 3.5274193091919107`*^9}, {
  3.527419952486923*^9, 3.5274199529576*^9}, {3.527512711024805*^9, 
  3.5275127116256685`*^9}, {3.5275127644316*^9, 3.527512901859211*^9}, {
  3.5275136287544355`*^9, 3.5275136432953444`*^9}, {3.5275137113832493`*^9, 
  3.5275137255536256`*^9}, {3.542103276780115*^9, 3.5421032832837653`*^9}, {
  3.542103388313267*^9, 3.54210340594503*^9}, {3.5421034658830233`*^9, 
  3.542103515380973*^9}, {3.5421036416415977`*^9, 3.542103648361269*^9}, {
  3.54210379698213*^9, 3.542103844768908*^9}, {3.542103891419573*^9, 
  3.542103907426173*^9}, {3.542103992493679*^9, 3.542103992941724*^9}, {
  3.542104557610185*^9, 3.5421045664020643`*^9}, {3.542104601371561*^9, 
  3.54210461196362*^9}, {3.5421046745348763`*^9, 3.542104678190242*^9}, {
  3.542104738968319*^9, 3.5421047432647486`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104151436572*^9, 3.542104417661192*^9, 3.54210456835526*^9, 
  3.5421046152719507`*^9, 3.542104679863409*^9, 3.5421047099624186`*^9, 
  3.542104750458468*^9, 3.5421064619303665`*^9, 3.5421064937503667`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104151436572*^9, 3.542104417661192*^9, 3.54210456835526*^9, 
  3.5421046152719507`*^9, 3.542104679863409*^9, 3.5421047099624186`*^9, 
  3.542104750458468*^9, 3.5421064619303665`*^9, 3.542106494518367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104151436572*^9, 3.542104417661192*^9, 3.54210456835526*^9, 
  3.5421046152719507`*^9, 3.542104679863409*^9, 3.5421047099624186`*^9, 
  3.542104750458468*^9, 3.5421064619303665`*^9, 3.542106494606367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Further output of \\!\\(FindRoot :: \\\"lstol\\\"\\) will \
be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104151436572*^9, 3.542104417661192*^9, 3.54210456835526*^9, 
  3.5421046152719507`*^9, 3.542104679863409*^9, 3.5421047099624186`*^9, 
  3.542104750458468*^9, 3.5421064619303665`*^9, 3.5421064946523666`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Fsol", "[", 
        RowBox[{"i", ",", "j"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", "resol"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "resol"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"DataRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "0.1", ",", "0.2", ",", "0.3", ",", "0.4", ",", "0.5", ",", "0.6", ",",
         "0.7", ",", "0.8", ",", "0.9"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", "Black", "}"}], "}"}]}], ",", " ", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"i", ",", "j"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.529120443921875*^9, 3.529120455421875*^9}, {
  3.52912076715625*^9, 3.529120769359375*^9}, {3.529120897109375*^9, 
  3.52912094278125*^9}, {3.542103678201253*^9, 3.542103678249258*^9}, {
  3.542103722586691*^9, 3.5421037246188946`*^9}, {3.5421040412535543`*^9, 
  3.5421040982642555`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1mQ2QllUVx3dCynRSA1Jp0FIpETVLUjRHr2KmTEkhKpoiMzgqGX5C5Iia
oI0jOBnrJOZH0KZEra2Ishqo4MuXLGLLu7vAsh/s7svuu9/7OuWg1rjJfZ7f
eeb+n30ZZu78z97n3ufcc/7/c577njTrrqtu+UJJSck1w0pKDo36r3Ts5M//
r3EhzhhuqLzj8/875O9Zw/7PDbsN74sMhj8bPPRvv+Gl/vk2w6ccgqUHDK/1
j3cYvtxv2GW43q/fY/iX/gX7DEf/CoITP4ceM4bxN/x71jD+gvEXjL9g/AXj
Lxh/wfgLxl8w/oZxKwhO4ji0n8kY+psRfzPib0b8zYi/GfE3I/5mxN+M+JsR
fzPib0b8Tefp0HFM/NQRf8H4C8ZfMP6C8ReMv2D8BeMvGH/B+BvyriA44eHQ
eZpJ+RX+PRnD+GYlvlmJb1bim5X4ZiW+WYlvVuKblfhmJb5pnRmah5lU3NQv
sI74C8ZfMP6C8ReMv2D8BeMvGH9D3SwITnR0aJ3JpPJS46Z+gXXEXzD+gvEX
jL9g/AXjLxh/w7pQcMXqxNA6mknxTvNS46Z+gXXEXzD+gvEXjL9g/AXjb1j3
Cq5YHcRf1U3VFeWd5qXGTf0C64i/YPwF4y8Yf8H4G9b1gitW5/FX64LqpuqK
8k7zUuOmfoF1xF8w/oLxF4y/Yd9ScMX6GPzVuqd1QXVTdUV5p3mpcVO/wDri
Lxh/wfgb9mUFV6xPw1+t61r3tC6obqquKO80LzVu6hdYR/wF42/YdxZcsT4U
f7Vv0bqudU/rguqm6oryTvNS46Z+gXXE37CvLrhifTb+al+mfYvWda17WhdU
N1VXlHealxo39QusI/4W+47A36H7Tu3LtG/Ruq51T+uC6qbqivJO81Ljpn4V
UmP0vmU24jk4et1++Xv6OebxPLjYqOvoc/oe+t7he5XaGMVjoKhdx3Cf0qJ2
3V/3KQn+FVL2ofdlnfWp88SuI/kIjs5ha2oedh3JX3D0HtWpedh1DPO92kVu
1qbmYdcRfoCv8Ib61DzsOsIn8Bz/Qk2pedh1hH/hc62pedh1hK/gaL1cah52
HcM+LRfv156ah11H9AAcvU8+NQ+7jmHfkHe/9+/TnZqHXUf0Bnyyf5/e1Dzs
OqJPYHis81QvVLexw6do337jR8ijctGDMuHRgK3HOrpuyNdy4XW50zFar1L0
pzzFY/g4NM8zKd7CP+Wr8hIc1qOEn8pDMPxSPirvwPBJ+ac80+8w5ZvySr9b
lF/KI+3zlU/KG+2LlT/KE+0jlS/KC+27lB/KA+1TlA9ax8N817xO8p55jJrn
0XkOxOfRb/kX1uNK2WdNkfqW5H3Ik41mZ8QeLbPZsNqj99tuWO13+uV2Gla7
nz52l2G1R+9ZY1jt0evWGVa7D//gHsNqj/Jyn2G1R+feaFjtUd41G1Z7dB4t
htUe5XOrYbVH8WgzrPYov3OG1R6dd7thtUd51mFY7RE/84bVHuV/p2G1R+/b
ZVjtr/v37Tas9uh9ewyr/Uf+ffsMqx0egdUe8oc+dnWMF8XxeD3Oq+fi/Ez4
CN/RAeoS+4CL1UXWYd1QJ0rj+SvtfXie9dmX9yi2r74X67BvdG59ohfr5T2S
cwLzHOtwrmB0hvdXneK99RzC+GyVc8lIvDZKXd9q66NHoa5VSz3fYRh9CvWu
2vZFn0K9q5V9s4bRq1Ana2XfGtHJeun7dxtGv8J1621f9It1qd/sS50Ho2es
y3z2Rc9YN6zz9dIX1Ju+sW7YbzeYvrFu2E83WZ8Q9h+tti7zw/vkNtHNdtuX
PiLsW3Kip+3Sx7SLjuZt3/CeL2d6GOprXvqcvOhqt+1LHwJGH0O97ZY+qEt0
ttf2De+l8qaXof72Sp/UY+uiC+yLfoDRD9ZlfthH9du6oV6keQzvivGS54rx
jOeK8YbnivEg7IvTeR32x+k8Db9P03kX5ms6j3iuWF7wXLE481yxuBEvdBZd
5BzRRfSMuIT3BJtNn4gL5xjaaywunCN29IO4cI7YQz1okHNsNH6HvxvlzA5f
Q/1IeAz/wt8hEl7CJ+LCOWKHH8SFeGAn38N744QH4XfqRquD1AXigK5z7ugy
54yucq7oIueIrnFu6BLnhK5wLugC5wCv8Zv8wU/qrNZd3he71lH9DtC6iD/Y
tc7hH3atW9qnax3Cf+xaVzgP7FontI9W3dc+WXVc+2DVZe1zVWf1e1LzCN2E
1/RxIa9LU9+Z9F1Df2dq/1Zm/Whkf07601Lpl8oEr7E8CHWn1t4fHNaHGvmu
rDc/Q53ZYXnCPugM7wFGp8gb9kF3eA9wWE9abJ/wfrFe7jUaLK/YJ7zHaDIc
9lHtond56V/ycr+St31C3coZDu9XumyfUMcSHN6v9Mg+/fYe4PB+pd/2qTv1
pKuHffWd1H1a62XrZt1e9aab8O1z/j3yzPdS92c/WLvw/m2Pb3EXNZ5xYs2q
9H3ZI5ev3HR9xQfu5m9tmDTmgrrU/Vj7nFu+OL+rxj1259TbbtmZvg/7cuXB
8RsW7HXlb+SWVMxsNjtxOHPw8Z8eflSTu63kgr3/vS9933Xa2KPWjatucZ+M
ffT2b2bS91vrr5j+kytH59ySyTv/98Mj07/zXnnHiuZ7ZrW7E+489slfXN2Z
ur/av7Tr7qfL8+6V0pkn/e6F9H3VPZVnD1v/ny53yRurXlvTkb6fGtaw4A/7
L+x1W8b8/KKT5yffqZUTbvp64wurTB+i838zjscq1xKP2IkbcfzubadPWP3j
V4yv0flvcYt8PN6xETtxJc6j5gxc89DBjcbfl/35f+CO8PF4z0bsxN3FeXDT
ZyOXHzOmyvj8qT//Gjfex6PaRuzkBXky7Yox86au2GX8PtGf/143xcejzkbs
5A159OulFc88e3ZyzzrJn3+ju9fHo95G7OQVefbcvovfzm3eZ/yf8PAJvQ++
1eKeHtx86mGPNduInbwjDzecUtN6xvTkHnbLi7c+VDY852a8ePrKlU+02oid
vCRPo/dLfv+Yvv2VY7ZNaXcD7807b0ddzkbs5C15fJjPq+Setqvv47KeZXm3
sO/tqoETO2zETl6T55F/yb3tghGTzjmmtcuNHPGlGaNmd9qInbyHB+N8fDtN
174yccm274/vdS+d+7OB817tthE7vIAn6zwvk3vd5TfUXn/93H438YY/Lpzx
aa+N2NG3BYvP+ejJqcnvGyvfufGsf148YHbmTZtZsezGFQPu+AcO3/3Qsf1u
7MvTrn147lqrh3dcdN/yEc9UuMbxs0ft63zMNflxWep3EZ5jHdZFX+cueOrm
0XuS+jz7sknnTpk7z134282XHDd8cczXCuMpvD26qeyDqmc3mb0l1uFQf9fb
PHj6tZi30+/adtyMDe+bHZ2Gp9iZB09nxrzdVTJ/9cEPk++2RbGOw1PszIOn
8PajyYfXXfzoHrOj82F9rrV58BTejn7q2U8eP7bR7NQB/R5kHjyFt5EutJid
OqHfi8yDp/B2tc/j5LuROqLfk8yDp/A20pXku5I6o9+bzIOn8La24cPL9pyV
/B5JHdLvUebBU3h7q9eh5LuUOqXfq8yDp/D2Y69DyXcrdUy/Z5kHT+HtYq9D
ye+R1Dn9XYZ51L0T/rb2O0fem/BGf49siHlYcvO735vYulr62ZIS6ua40YcI
Od94F/UnG2MerLURe1Q3trsOn6eb4nzdZPbZ/px2ubN8Hu20EfsT3o/d7i3v
f42N2KM82edafBz22Ig9iuP+OP6NNmJ/wOtsqxvldbfFRuxHeR094FZ6XW2z
EfsKr5Md7jyvmwdsxH62r2Odruo3bSMXXZq3EftmX6d63I2+bnXZiP1aX4f6
XL+vSz02Yuc7ovKv100bPP4ld8PsKfOuan7NDZ7/4PNLL/yT63jk4GkLuwZc
+Yqps/8ysz+uiwPxPomO6z35ippto+tzffYc60z+qP3+7cP/7sb6PLjVLfxV
1RF3VyT38azLPqzDuszjuUiXl8d6+5pbG/uBX0senfN8x7jkXnzaGxPPf/qe
f6Tu0wdnRXnLPJ67zuvwW7F+r3bVXlczcR+1LtbJbbG+vhvr3vvuPq+XW903
vI5Vuxe8/lW5V31eZd27Xs/+5S71OlPr5noe73J1Pq/2uOE+z2rjvqXeLfP6
sTvuQxpi3dsb9xXNsY41uKN9XrXEutTkrvNxbnXNPq/3uz/7vGqL86zFdfs+
Ixf3HW1x33QgzrNcnMftcV9xII5LPo5Te5zHnXHf0BH3PV1xnuXjPO6O+4LO
uK/pcQ/7/brjPO512/1+PXHf0udG+P167Zx3xefOuXLOnCPnyrlxjpwT58a5
cE6cA+eC35wDfuI3fuEnfuAX740f5A15RJ6QN8/HeUGekAfkBXEnD4gzcd8f
x5U4E0fiStyII3EibsSFOBEH4vJ/tByRAA==
    "], {{
      {GrayLevel[0.5], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgnYl1MTxp9n/iolRZHqpQjZ1wgVIlk+O2WXVJQ1n32Nz77zEVqID6nI
GkmLEu0pKZUs2RKyJNmT7/6Z+726rqZznrPMmXNm5j4z5/9u1q33MedHURTt
K0Whf0VrffxeFsUFqi9TvYXqL6icru9FovdFC/RdT+0Pq1yi8gvRS2pfpXKQ
yntEG6mvub6fV32I6FXRSNFTLl8RnaMxI1Q+KVpX9XU0/jTVR8BP1ED1w9Xe
UOVaoo9Fs0SzRQeovYNomMZNUblabXeq/ELlJqJ6olrIIWokGioaZTlqiDYU
bSDaX3M2Ea0l+kDfM0QzRR+6fFv0kctZPoPpHveMaIxotOhpl6+JhrlkveWi
paIvRc+JXheNEz3rcqyoSmtvVea+hrsNvhG55njRJNF7onmiadbDQtFk0Xz3
jbOcyP2T5m4rnqNU1vQZsOf+lo/zGOg9IPsjlon1B1lWvleXWX9U9IBosPU1
wPPg9YnGLBY9rnovrfeEyr6ifl4H/T9s3qz3kNuwhaUa30xzh6tc17rbWLQO
5yJqKlpb1Ni63BubEB0mais6VPQv0V6iQ0QHM1e8aonnkaq3Fh0o6ihaobYj
VO7r82gp2tJ6fd3n/LbPke+jxGdz28k+Rc493Oc71uP2EB3kNdpYFuSYorUm
i45x20miEy3fCaLjvYdTRCeL9nQfvFZqXpci5We9Uz1ud+/jANFcyVZH4/qp
PFF0rNuRsYvnTLWNLBCN0thXRS1Ubx9pc9gXdoUvjrQtUeIj26rvG41vKfpa
9LLa3mRf7h9lvlO8DvaIXeIbtUVNrLM61iHfda3bKss11XPwpTE+0320bhMA
Kdb4CfY33/Kx3sNl2jbyvGrfeSXSByZ53FjbG/O/dHu17+Cbo61jeINRI9C1
+LwYKdcoj5vusWN89p1FnSzHAss11jbBPkrL/rztijOe7bVox8YqPnvqrFlx
/XvVa6m+U5FYByYtLhKjaojeKXKvNcyTs2K9F4rE2tLrtlX5t76rRG+IOul7
t2INNuG389X+nuh61bup/waVF4uuEN0mutV2gmwTVO8jult0l+gal3eKLhXd
LLpJdJXoDtHtoqvdz/eVboNvDWMt8reznI8VKSt1cOY3leur71rVN1TZKLJ/
7cjz2VTtDSLHcE8NVl9N1Z9UWV/leqL6qv8hahh5H1FuINqoTH7wvbfIO4s6
68IPvg3Vdon3dGOReLjKsrVR/19lzv3TayDnSGywzHsIm1rtuw85uE97F7k2
c5GHva42T871D7fTv8r1PSPXuK5Imf70Wn18RtQvE91iHSzmrNT+ZCQ/+DLm
NH1fpLKH6EzrjP2d4fJi65M7AJyeqbkzRN1Un6PyHdGFqvcSXe41z7cc2MI5
1j16PtsldtTTY1nvPI+92vsd5PXws6n2px8i8eblSEzCZ9+y3+A/nGcT++l4
20aVz/Ab49TEIn0VX5xum5/mNUa7je9XvWY15k32eqyD33IPnGt52Vt92xR6
/Fz1pqoPJWZQuUh0H+ep7/ttM9gO92Vf6+ZBf+NX3IsP2R/6+xv/GOBvfGag
v++0TgbahjeybXyAreI79oOGtodTLDc66Wwdo/fjrHu+T7Au0c8pmtu9SEzD
ptApezze/cz5pUx9E5udal2yRhfbAd8ne030zz13ltc40Gsjy0Hmy/chHocs
g302nBHxA3VijB9Ev4qWFIlZA4o1MctAn8tvRcZYc7EPx5zPRs5jfn3RMteJ
DYf47Pt53krPHeazH+CxP3kuWAUWg1fEiduVicnfFnmvzLO9MIY4EUwj9sW3
J3kMNryJ129WZEzUz+tt4xiaOHuZx9RzucTjwRP8BTvnPnvE38N9BnwTe2wr
2q7IWGgbfxNXbO3vFlprIlgpmieaWyZeHBcZWxxgfREzEdfcD/6r/7+RsRa8
ty/yTuE+6VDknbi757DXpd7v9sZq7rR7wHm13RWJH71sH9V4cY7Pc7l5wI+4
jPhsB58d53BsZDtrH+y9sdfNiBW0TojGirZQWyvvYSvvv7X58T3KOhhmPf9g
G1lpGZBlO/H8Acz1GeOHYGQPtXUH933utIFnzxiLhkXqhjb8FCx6xroao/7R
lvMJ++z/VI4VDVG9eSUxv6Hxu2XkPY2O2vjO4m7ARsELcGICdz57rqRNgS/g
Cr4E7nA34E83+Xug57Ef8Ip2MGorYxm41t88WGMHtf9Ypv6GGH8GR2IeOAfe
tbNdoKvWxiOwBLwHG873uf5m+9g6Mmcg7kc+7gjsAkweYt0g66Xua6q97Ua8
F2tySMaRd4IT5JBVGrO7vt+KzCvBFGJW8hL2R07Sx7L09nlc4jWIf6izn51U
/6lMuwf7z/UerrKd8k3cxJ15g8/pCtvyOM0dqr4tK2vipD4+xyvNg3O/2n13
u/9a6+Qq95Fr7FhkHLijeNYWLS/zjDe2P4DD5AbE+7tHxhjcTwMj8+j+kVgL
5uIru0bm2OQW3BGHeT4YDBaTo1TnveTB1Xkv3ye5n1zrBPNjzgyPJSfuYlnI
WcD3A732Q5G52AOR+RAYQ66yeWSORA6zc2TORn62RWT8wfsCd0ZH82J9MA4c
It+hvZP3sLfP7FD3t7MstJHrzRavWWXel2ABuFGNDZStfa6cLxhHvgJ2gpkb
eRzYMSPSd++NzG22dh/62MHzwTt017xIXAUjwauJjsX3R55IDO5rjPzbuma9
vSxfE3+zxjjj2q6Wq43HtbTs4CW5Pdi4hffQ1uOq/L2t5WvnvtrGds4HXG3l
uVuaHzJjc/tU26HPk7PewBh1nerTNWaa9UUsgc56mA8yNfLaTS0LZ0WeX89n
x/k2dh85f13vubHPoKV5MI78lVycnBzM5n7kniRP39Dyb+N5rHdHJH7fFvmO
xLsP85tHvjH9Yb68E63tc6qyLezlOB+8a+x+8lrepXiLauh1aCPHfV/tC42f
yMJaNc2rrvfcyG21LF8d75lYG1smDts0MlcnjzjEekaPjYUpg9TepJLxPHEc
GLRbZGxKjAaWEa8Rt4Fz+CQx22Vu49591HHsI9ylkfE9frGL6j+X6avE++iQ
nKE6T4Av/ryH7bMVMVaZWEM/esfvJ4HB9muwEqwBqyYQszv2OM9tXcyXeWDV
Hs53uBfB2pM9v6f7q+NWyuoYkxJ8el1z+2EfFed/oq7Fmrc57mDwr57xcarz
yL9U3hJ5d3CHXBr5ZrOW6jyM8ga5SmX/MseoWuwbmReThwwv8276RO2fq/zM
sdxXoqVl5jM3R47hHltouWpUMh7C96epnCc6SvWK2v9WfWfV747EGjBnluPE
syPvvdWRbzn/Vrl3ZO5P7DvTc+Fxgccw9h1Re9XLSvp7J/v8xZGYFGq/MBJj
eAh+0fv7TuV+kXk7bw8D0HeZcdCHkfl3LY1fHvlOsL7qKyPfKhqqfmVk7ri2
6tdHvhOvp/onxo/aqveJzJ/qqv5FZG69jupXR75P1KmkDtBF70idobvbI998
8ZXpKm+N9OnJkTFaD+vr8shctmYl3wp4JyCO7+cxzPlO5bdlvis193zewxvp
v1NV/wXbFJ3J+Mh5Z5j/75H131TeGJmDNqjkPtnvDZFv6NjF945NiFGe9Flz
5hdF3gf4x7uRekJf90W+s4OviyJjcXD77cg7FX+dE/kOiM/Nj7QhbOnBSL2i
30sifR7ffz/yLDiTKyL1hx4HRZ475/9UZG4JNnwcGafilx9F6gzdPR751kB8
+lmkTWPbAyJjRLDz08iYmNh4SaQu0ek1kfkzePllpO6xgWsjc/nzIvN5/BB/
vCwypsF331O5biXfjZ6OtDls7yX7xlk+W3JJ6sR+9Sr5Pv2fyJjwzMi4ED2c
GxlDMvZsj6eNPmLI+pV8Y3vOMp3r9mftc1+r/DZyDGPh3TMyNn4t0tZ+jnyj
xId+jMRrMKq31zrPMmA32M9NkfH5meaDbL28L95HwJUVke/mxNHfRMbUPb2/
B7z/vvZD/HFkpB/ij1fhf5FnUs8yn+HxvK8+Yl/oZ5/H3slFTo+Mfwd5zLtF
5gLdI+Pnoe6jnbiaduJkym4ec4n7uL/IOXpE8oDfw57L+B6e2zVyXe4j/Pcp
4y0502D7MmNOM0/uz9d8hz5d5m9E6xXpx0PNnzuL8dxz73n+xW7r6rWaVXKt
MZH3ZJfIu5G3xsGWgdzrafMnNuANEJzaTHOfUf0Njf01cu1G5jfcc+F1qmUg
dqJODEB5its7u4/4gLj45Mh44aTI+rEe38VzW1SS/8RIuZCBGOhAfXeMlJH6
COMb8tJGPEPby8ZD4pBX3H6Aef3p8SO9xyMjz5oxzBvhdnJcYjXiNPTAmBYe
f0RkH7p+wja2nTGZd5WNK9k+WuOOER0dGft2jryziKGJLyiJrYkp6G/ldcd4
rdfLjJt39ZgJrtNGH3cq/MdZzjfLjNHBSuJZchXO9gSNOT7ye2qZOQt4VC3H
/rYfYj9wbfNKxgrjI/nBF0zn7WW85WTeJM8lD3rLe5niNcBx1p3idtae5nU7
my982Pd474u8aZplJrc9w77WxXb1jm3nJNvP22XaU7ci22d6LnkS/d1tb4zj
7qF9tsejv9E+Z95eRvsMiSdnee4Mz2H8V5FYDWbz5oQsF1m2OR5P+W6Z9w3v
HnM9hrHUwSzKea4zdo7rp9tn0QMYtaDMO2mBv9EL+qH/Bo+fb/6c2XSf7ccq
PyoTT7nP0aOG/vPux28wYCjxKW80vM98WWZMxh1PrkDOwN3JO00b13nnb+v9
k6PzPsLbCOMZs8o84EV8wP3DN3cQ74jtPBds/9Sy8Vaz0HshLtvPstWwnLxZ
8ts4fovPEhsSI75geeDJ+2RP3xncL+Rz7Os673EP13kD62A+3K1Lvd/GkfI9
Zp86xn4K4bPkYkfbh7EN8iFyMHIn/Bg7buU68Sj55om2T+yQc+DOY01yyWPN
EwwDv8Cuo4wP8EcuxnKHgjFgDbhEHsRd29v43NEygElHGovgcZT588188sQN
vcYGlv0I8xzmM2nu+4VzHmb9cJ6PF/n+ydltWuTdzh1P7ED9G8uJzF/5PGlb
Vua9Tp5N7k1u3sF8WIt+xk0sMu4jX+O9hfeqFR7POw/txH/kFrzdkb/TttLj
eW9hTvsiY17k4rdU8jHGkDOS2/3iOjyWmw/vKivMh7cp+sg3+L14qfeFD+FL
xHPYGLEFMQm/3exjOyR/4vdFfgct3Y6z0U5+NaHIXGqxfYFY4APbPPwX2W4/
LLOdtarMk7nM+8y6YC7xBHPwm/eNCez9O58n99C3PoevXacd3qxBnMq75Ude
F518b73wNvK9zwe/wi/4rWqR8QTZsGvsu5Pt83DbFTJ+bjmRf+PIGBHsBE8b
GMPAxIuMgdTBN97M0CV6xOfBqcW2h53cTp0x6Iw3H3SGvlinymdFe53IvIL8
mDwZ+0Ef6Izf2pq6/oJxCf8n9m3mdcGfMM/ZthHkw07qRtbbG0uZw53P2xe/
6WKnrLmr1+VM+F2khe0d26r2F+r4COePj3HuyF7b+1pofGzqMbzj44Ostb3r
+MIuXmu5zwXfWeJ1n/AY5MEfiNN5Z+lqv2jlOrbPecKD+g6W4RPbyv22VerN
bKfIhg0TKzU3jnGunO8/fwtQps6Qh1iLOIw4lvVZu6vngoHgGbEJsUIH4/Bm
xkPuGt6Fyes6Glt5e+VtvrXbyaV+tY/z5sd7JTgMz+M8nhgE/sQgtB3vtYhB
iGnA8O7eyx/G1U2Nk5MtH3zQP3YAbnHnEq8QV4y2zMRjrLW5+VfHuJ28FvcF
Mdcc+0V3YxV2U41XnBGY9Zb5EEeNt5w1rdvPjCecD/cw98JMy8O98394Wqpn

          "],
          VertexColors->None], PolygonBox[CompressedData["
1:eJwtlWmMT2cUxu//vYIMGZOx1jLWKqaMwRhMxxja2rfBxyYySX00qH2rNUET
hKS1xBBSBClBqK0d+5iW0c3YSm2ttfbYEvyenPPhyXOec+5973nPe857mxYW
FYwOURSNB5XADMQc+EIiirLiKOoKbmA3A/eIfYquBc/imX/gFujtxFLQx9E5
6NvoluAh+gjYhr0RpBH7F10f+zLojG4JdmOn8r4S6YK+hl6PnoU+EOzd70Ej
Yl+jlxG7gs5G54EkfO3x/Qq3Qu9Tvugx6I/Qe9Bv0SfR+ehkeAj6T7gnOgUe
iT4Pd1OOPL8TPQd9AryOLEfl+q2/mwkPRPcA1bF74DsL/wja8OwG0JDYYfRW
7C2gCXqx59oW7o8eGyzXA8Rbo3uBVHxj8F0OViPVSnueie6Orgo3QZcGq4Fq
kQb+Q08BhcTK0ZnEFqLfRJZDU/Q09DjtHd1R76JTsX8HHdBFwc5CNVPtGoNN
2Olgn2rve82ABxArC1Zb1Vy1P42OE3YmOhvloFz0jUv4joJOCeuJZsQGgyx8
NdBr4fXeW9mqM7H/g/WezkRncwvdALsO/Jl6Ba6bsJ5UbxZ77bSm1r4DNyZe
D/4cPTfY2apH1au1wSrsFeAnYsdAFvZK0Dy2M9PZqcdLiK3yXukIDyL2c7Bn
vwSvsF8Gs7Wm1tZMaDZGod9gf4hvM/YX4AX6brCzU8+r9x+gm2PXh3vHlrNy
X6ecvWfUO+/QS+DH6nH1GtwntpyUWzV8q+F+6HTvgW+0d1CCnQcPj23GNeua
yRv4fgNVEt7TxPqCNOyzvPMMfh6sF+RTTD2Q4We+3HNW7jt4/j78l+eS7LOn
mcn0b3wH14qt9pqxBb6Hhp7jI/iC90aKz+rfcM2EzYhm5TpcB10BOqF/8G/n
wsNiuzN0d6iHD+L7BH0P+wjPzENP0Lq6u/C1jW0NraU7cDqx+cGefYAvl9j+
YLO9BtSNbYY0S8rhKrFzIAm7FLSLbaY0W5q5qcQmgQLsMnwZiqErYx8FH6Mv
opOxT4P26EU+6+l+lmfgoF4FbdBfoTsQL9GMop8Eu3u1R+1V39C3tGZFsDW1
tu6IycH2oL0Ua0Zi26P2qjvsabA9aC/KeaLPZLafwYZgOSt31XB8sBqqlqrB
H+ih+of4jG6CZwe72/VP0b/lg9i+rZk4pNqgc3zGt/qMa9aX8s5NP9Ncn+nt
8Ah0vs/AXniLz0qOr6Uez/OZ2gVv9LW6em6qoWqpGo4LdgfrLlaNf0Gf8lnT
nau7VzVWrXVm5fj2+Gzkey7vAThk1Xc=
          "],
          VertexColors->None]}]}, 
      {GrayLevel[1], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFV3dsl1UU/b37YSIJJJBALAkoVapUKVPLHmV1sVqWCEHKPyJoAdl7K0OG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          "],
          VertexColors->None], PolygonBox[CompressedData["
1:eJwtlVXQlVUYhc9+DwgSEsaQMj/CBTNijBcqiIAoCCIiEqJeeaOg1E93d/MT
IihISKOELSjoUArSoYRKSZcirc+axcUzs96zv/2dvd9YX86b7Zq0jUwmkwv5
4D+CNimTeRp+RmezmUxn9LOwk3gSdETfCVPQ06EHui7sQS+AoejysAj9HnRB
14Ed6OB9ndDPQCfidfAk+i0Yhh4Ir6LHQXGeLQSD0I2gF2uj4R10grHo/Kx3
R9eDvcS34F30U9AeXYD13ugGsJ+4a/is3SBf1kg/B11Ym6pn0EVhGnoZjEVX
hhXoj6Av+l6Yje4PzdCj4C7eNZ64HTo/5KEL89tgdGM4QlyMeDS6OZzWs1AN
/TbcQPeEhuh+UFC5D+dOOVPuisJw9CvwF2tFiIehX4Y+xPNhCPolOIzuHdbK
oXI5nPhx9E1qPRLdHeort3AH632JmyS/U+9O0AFdG7ayNhFy0bXgFzUO6+3R
NSGXeCb0SX7nb+glMBKdA5+od8J7tUd7OxDXSK6ZarcYRiSf4Xg4p8ptU+WE
eBy0Td7zE/pTGJNcg1Po7eHe0hl11sHwujSUzPqOuuvz6gHW1sCjyTnJYe0H
nRk9E8oQLw2fXTVT7ZaHe2E8lCC+SPwaegKsRH8ND6InQznWNxJXT+5Z9e6x
cK1UI9XqLLRIvoPusi2ca82YZm1zeBbVU+qtk+FcKEfK1edQRc/C3fzfZ8R5
yb99gb4CD6MfgavhHCgXOvMg4lnhXu6vmWatAkxBV4VvWbsn69nUO1YTVyJ+
Ijln3xOXJn4o+c6l0B/rt+SeV+/vC89mT/gA/SGUSJ5JzebksJfIY+Q134T/
+zG4n/jLcC5Vw0vhO+qub8DfxAvDXqOZ0Gy8H55deYK8YUJ4FtXD6mXNlGbr
BejB2qawV7TWDKN3x20vSPYu1Vi1bgnnw54kb1LNBoRrrtrLs86h/wmfTTn8
Cn0NDmecs+vhGdesy/NkvHNgQPLMHwr3nHrvBHuGEM+VJybndF74jDqrPGM9
uizPz0Kf5Pmh4Rqqli/C78Q3oVVyD25AXwjfRT2iXjkR9hLNqGb1aNir5OHy
8jNhr5IHygsPhL1UHigv3BX+Nsgz5Z0Hw7mVB8gLfg3Pmr4R+lb8GfZy3Vl3
XxuutWauImffEvYSzbhm/btw7y6FB1gfEfYu3Ul3+yN8V+VIubqPZ6bprPCv
vCH8rdA3Td+2H8PvUs6Uu8vykOQ92ls5673q6VXhnlXvqmdnoP8H4b3Zfw==

          "],
          VertexColors->None]}]}}, {{}, 
      {GrayLevel[0], Thickness[Large], 
       TagBox[
        TooltipBox[
         LineBox[{646, 794, 707, 802, 706, 798, 699, 797, 700, 799, 697, 757, 
          841, 756, 787, 694, 853, 695, 693, 753, 840, 752, 785, 690, 852, 
          691, 689, 749, 839, 748, 783, 686, 851, 687, 685, 745, 838, 744, 
          781, 682, 850, 683, 681, 741, 837, 740, 779, 678, 849, 679, 677, 
          737, 836, 736, 777, 674, 848, 675, 673, 733, 835, 732, 775, 670, 
          847, 671, 669, 729, 834, 728, 773, 666, 846, 667, 665, 725, 833, 
          724, 771, 662, 845, 663, 661, 721, 832, 720, 769, 658, 844, 659, 
          657, 717, 831, 716, 767, 654, 843, 655, 653, 713, 830, 712, 765, 
          650, 842, 651, 649, 801, 705, 800, 704, 804, 709, 763, 762}],
         "0"],
        Annotation[#, 0, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         LineBox[{647, 795, 708, 803, 703, 761, 760, 789, 702, 788, 648, 710, 
          806, 622, 764, 623, 807, 711, 652, 714, 808, 624, 766, 625, 809, 
          715, 656, 718, 810, 626, 768, 627, 811, 719, 660, 722, 812, 628, 
          770, 629, 813, 723, 664, 726, 814, 630, 772, 631, 815, 727, 668, 
          730, 816, 632, 774, 633, 817, 731, 672, 734, 818, 634, 776, 635, 
          819, 735, 676, 738, 820, 636, 778, 637, 821, 739, 680, 742, 822, 
          638, 780, 639, 823, 743, 684, 746, 824, 640, 782, 641, 825, 747, 
          688, 750, 826, 642, 784, 643, 827, 751, 692, 754, 828, 644, 786, 
          645, 829, 755, 696, 796, 698, 791, 792, 793, 701, 805, 759, 790, 
          758}],
         "0"],
        Annotation[#, 0, "Tooltip"]& ]}, {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxtnXmcjXX/h4cQWdKUyr60YOyyZbtTlpRiso+lZMlOdhJZG0LKSPYyB1lC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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[LineBox[{3124, 3164, 3125}],
         "0.9`"],
        Annotation[#, 0.9, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3123, 3163, 3105, 3160, 3104, 3161, 3106, 3162, 3108}],
         "0.8`"],
        Annotation[#, 0.8, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3107, 3089, 3082, 3158, 3080, 3157, 3079, 3052, 3051, 3156, 
          3043, 3155, 3050, 3071, 3078, 3096, 3103, 3115, 3122}],
         "0.7`"],
        Annotation[#, 0.7, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3088, 3159, 3081, 3059, 3053, 3031, 3025, 3153, 3023, 3001, 
          2999, 3152, 2998, 2975, 2974, 3151, 2967, 3150, 2973, 2991, 2997, 
          3016, 3022, 3042, 3049, 3070, 3077, 3095, 3102, 3114, 3121}],
         "0.6`"],
        Annotation[#, 0.6, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3087, 3064, 3058, 3036, 3030, 3154, 3024, 3006, 3000, 2981, 
          2976, 2957, 2952, 3148, 2950, 2932, 2930, 2912, 2910, 3147, 2909, 
          2890, 2889, 3146, 2883, 3145, 2888, 2903, 2908, 2924, 2929, 2944, 
          2949, 2966, 2972, 2990, 2996, 3015, 3021, 3041, 3048, 3069, 3076, 
          3094, 3101, 3113, 3120}],
         "0.5`"],
        Annotation[#, 0.5, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3086, 3063, 3057, 3035, 3029, 3010, 3005, 2985, 2980, 2961, 
          2956, 3149, 2951, 2936, 2931, 2916, 2911, 2895, 2891, 2875, 2871, 
          2859, 2855, 3143, 2853, 2839, 2837, 2823, 2821, 3142, 2820, 2805, 
          2804, 3141, 2799, 2788, 2783, 3140, 2787, 2798, 2803, 2815, 2819, 
          2832, 2836, 2848, 2852, 2866, 2870, 2882, 2887, 2902, 2907, 2923, 
          2928, 2943, 2948, 2965, 2971, 2989, 2995, 3014, 3020, 3040, 3047, 
          3068, 3075, 3093, 3100, 3112, 3119}],
         "0.4`"],
        Annotation[#, 0.4, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3085, 3062, 3056, 3034, 3028, 3009, 3004, 2984, 2979, 2960, 
          2955, 2939, 2935, 2919, 2915, 2898, 2894, 2878, 2874, 2862, 2858, 
          3144, 2854, 2842, 2838, 2826, 2822, 2809, 2806, 2792, 2789, 2777, 
          2774, 2765, 2762, 3139, 2761, 2750, 2749, 2738, 2736, 2726, 2724, 
          3137, 2723, 2712, 2711, 3136, 2707, 3135, 2710, 2719, 2722, 2732, 
          2735, 2745, 2748, 2757, 2760, 2770, 2773, 2782, 2786, 2797, 2802, 
          2814, 2818, 2831, 2835, 2847, 2851, 2865, 2869, 2881, 2886, 2901, 
          2906, 2922, 2927, 2942, 2947, 2964, 2970, 2988, 2994, 3013, 3019, 
          3039, 3046, 3067, 3074, 3092, 3099, 3111, 3118}],
         "0.3`"],
        Annotation[#, 0.3, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3084, 3061, 3055, 3033, 3027, 3008, 3003, 2983, 2978, 2959, 
          2954, 2938, 2934, 2918, 2914, 2897, 2893, 2877, 2873, 2861, 2857, 
          2844, 2841, 2828, 2825, 2811, 2808, 2794, 2791, 2779, 2776, 2767, 
          2764, 2754, 2752, 2742, 2740, 3138, 2737, 2728, 2725, 2715, 2713, 
          2703, 2701, 2695, 2693, 2687, 2685, 2679, 2677, 2671, 2669, 3134, 
          2668, 2661, 2660, 2653, 2652, 3133, 2651, 2644, 2643, 3132, 2640, 
          3131, 2642, 2648, 2650, 2657, 2659, 2665, 2667, 2674, 2676, 2682, 
          2684, 2690, 2692, 2698, 2700, 2706, 2709, 2718, 2721, 2731, 2734, 
          2744, 2747, 2756, 2759, 2769, 2772, 2781, 2785, 2796, 2801, 2813, 
          2817, 2830, 2834, 2846, 2850, 2864, 2868, 2880, 2885, 2900, 2905, 
          2921, 2926, 2941, 2946, 2963, 2969, 2987, 2993, 3012, 3018, 3038, 
          3045, 3066, 3073, 3091, 3098, 3110, 3117}],
         "0.2`"],
        Annotation[#, 0.2, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{3083, 3060, 3054, 3032, 3026, 3007, 3002, 2982, 2977, 2958, 
          2953, 2937, 2933, 2917, 2913, 2896, 2892, 2876, 2872, 2860, 2856, 
          2843, 2840, 2827, 2824, 2810, 2807, 2793, 2790, 2778, 2775, 2766, 
          2763, 2753, 2751, 2741, 2739, 2729, 2727, 2716, 2714, 2704, 2702, 
          2696, 2694, 2688, 2686, 2680, 2678, 2672, 2670, 2663, 2662, 2655, 
          2654, 2646, 2645, 2638, 2637, 2634, 2633, 3130, 2632, 2629, 2628, 
          2625, 2624, 2621, 2620, 2617, 2616, 2613, 2612, 3129, 2611, 2608, 
          2607, 3128, 2606, 2604, 2602, 3126, 2603, 3127, 2605, 2609, 2610, 
          2614, 2615, 2618, 2619, 2622, 2623, 2626, 2627, 2630, 2631, 2635, 
          2636, 2639, 2641, 2647, 2649, 2656, 2658, 2664, 2666, 2673, 2675, 
          2681, 2683, 2689, 2691, 2697, 2699, 2705, 2708, 2717, 2720, 2730, 
          2733, 2743, 2746, 2755, 2758, 2768, 2771, 2780, 2784, 2795, 2800, 
          2812, 2816, 2829, 2833, 2845, 2849, 2863, 2867, 2879, 2884, 2899, 
          2904, 2920, 2925, 2940, 2945, 2962, 2968, 2986, 2992, 3011, 3017, 
          3037, 3044, 3065, 3072, 3090, 3097, 3109, 3116}],
         "0.1`"],
        Annotation[#, 0.1, "Tooltip"]& ]}, {}, {}}}]},
  AspectRatio->1,
  Frame->True,
  PlotRange->{{0, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5421040990223308`*^9, 3.542104156440072*^9, 
  3.542104419914417*^9, 3.5421045803054543`*^9, 3.5421046379492183`*^9, 
  3.5421046918306055`*^9, 3.542104723793802*^9, 3.542104756291051*^9, 
  3.5421064662563667`*^9, 3.5421064965533667`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"c", ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.5421048088193035`*^9, 3.5421048122806497`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerics: c=0.5, s=0.5 (Fig 3b)", "Subsection",
 CellChangeTimes->{{3.5275129799815454`*^9, 3.527512980642496*^9}, {
  3.527588202429216*^9, 3.5275882072060847`*^9}, {3.5421048232567472`*^9, 
  3.5421048282962513`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"c", ",", " ", "s"}], "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0.5", ",", " ", "0.5"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5421014900454593`*^9, 3.5421015735248065`*^9}, {
  3.5421016059340467`*^9, 3.5421016557440276`*^9}, {3.5421025341198564`*^9, 
  3.5421025349519396`*^9}, {3.542102588170261*^9, 3.542102588587302*^9}, {
  3.542102642387682*^9, 3.542102644179861*^9}}],

Cell["\<\
The fixation equilibria are unstable in the area between the lines (based on \
equations (3a,b))\
\>", "Text",
 CellChangeTimes->{{3.527415065029104*^9, 3.5274151209094563`*^9}, {
   3.5274151690987487`*^9, 3.527415217268013*^9}, {3.5274152505558786`*^9, 
   3.5274152871484957`*^9}, {3.527415368465424*^9, 3.527415370828822*^9}, {
   3.5274155031991615`*^9, 3.527415527163621*^9}, 3.5421025990253463`*^9, {
   3.542102691300573*^9, 3.5421028245048923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"alpha2", "-", "alpha2crit0"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{"alpha2", "-", "alpha2crit1"}], ")"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"alpha1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"alpha2", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", "0", "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", "White"}], "}"}]}], ",", " ", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.542102836010042*^9, 3.5421029119496355`*^9}, {
   3.542104058638293*^9, 3.5421040633507643`*^9}, 3.5421043223676634`*^9, {
   3.542106376260367*^9, 3.5421064536383667`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"resol", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "0"}], ",", 
    RowBox[{"i", "\[LessEqual]", "resol"}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "0"}], ",", 
      RowBox[{"j", "\[LessEqual]", "resol"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Fsol", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "=", 
       RowBox[{"-", "1"}]}]}], "]"}]}], "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", " ", 
     RowBox[{"i", "\[LessEqual]", "resol"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"alpha1", "=", 
       RowBox[{"i", "/", "resol"}]}], ";", " ", 
      RowBox[{"alpha2", "=", "alpha1"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"solval", "=", 
       RowBox[{"sol", "[", 
        RowBox[{"0.4", ",", "0.3"}], "]"}]}], ";", " ", 
      RowBox[{
       RowBox[{"psol", "[", 
        RowBox[{"i", ",", "i"}], "]"}], "=", 
       RowBox[{"p", " ", "/.", " ", "solval"}]}], ";", " ", 
      RowBox[{
       RowBox[{"Fsol", "[", 
        RowBox[{"i", ",", "i"}], "]"}], "=", 
       RowBox[{"F", " ", "/.", " ", "solval"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", 
          RowBox[{"Min", "[", 
           RowBox[{
            RowBox[{"resol", "-", "i"}], ",", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"u2", "/", "u1"}]}], ")"}], " ", "resol"}]}], "]"}]}], 
         ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"alpha2", "=", 
           RowBox[{"alpha1", "+", 
            RowBox[{"j", "/", "resol"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"solval", "=", 
           RowBox[{"sol", "[", 
            RowBox[{
             RowBox[{"psol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "-", "1"}]}], "]"}], ",", " ", 
             RowBox[{"Fsol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "-", "1"}]}], "]"}]}], "]"}]}], ";", 
          " ", 
          RowBox[{
           RowBox[{"psol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"p", " ", "/.", " ", "solval"}]}], ";", 
          RowBox[{
           RowBox[{"Fsol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"F", " ", "/.", " ", "solval"}]}], ";"}]}], "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", 
          RowBox[{"-", "1"}]}], ",", 
         RowBox[{"j", "\[GreaterEqual]", 
          RowBox[{"Max", "[", 
           RowBox[{
            RowBox[{"-", "i"}], ",", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"v1", "/", "v2"}], "-", "1"}], ")"}], " ", "resol"}]}],
            "]"}]}], ",", 
         RowBox[{"j", "--"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"alpha2", "=", 
           RowBox[{"alpha1", "+", 
            RowBox[{"j", "/", "resol"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"solval", "=", 
           RowBox[{"sol", "[", 
            RowBox[{
             RowBox[{"psol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "+", "1"}]}], "]"}], ",", 
             RowBox[{"Fsol", "[", 
              RowBox[{"i", ",", 
               RowBox[{"i", "+", "j", "+", "1"}]}], "]"}]}], "]"}]}], ";", 
          " ", 
          RowBox[{
           RowBox[{"psol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"p", " ", "/.", " ", "solval"}]}], ";", 
          RowBox[{
           RowBox[{"Fsol", "[", 
            RowBox[{"i", ",", 
             RowBox[{"i", "+", "j"}]}], "]"}], "=", 
           RowBox[{"F", " ", "/.", " ", "solval"}]}], ";"}]}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{"alpha1", ",", "alpha2", ",", "i", ",", "j"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.527415386421243*^9, 3.5274154673676386`*^9}, {
  3.527415553821954*^9, 3.527415631713957*^9}, {3.5274156809547615`*^9, 
  3.527415759507715*^9}, {3.527416859279109*^9, 3.527416869503811*^9}, {
  3.527416902641461*^9, 3.5274169643401794`*^9}, {3.527416996276101*^9, 
  3.5274171327223005`*^9}, {3.5274171696453934`*^9, 3.527417257611883*^9}, {
  3.5274172891872864`*^9, 3.527417305000024*^9}, {3.527417335113325*^9, 
  3.527417412734939*^9}, {3.5274176767145233`*^9, 3.527417680860485*^9}, {
  3.527417895449048*^9, 3.527417936828549*^9}, {3.5274190007584047`*^9, 
  3.5274190012390957`*^9}, {3.527419306788454*^9, 3.5274193091919107`*^9}, {
  3.527419952486923*^9, 3.5274199529576*^9}, {3.527512711024805*^9, 
  3.5275127116256685`*^9}, {3.5275127644316*^9, 3.527512901859211*^9}, {
  3.5275136287544355`*^9, 3.5275136432953444`*^9}, {3.5275137113832493`*^9, 
  3.5275137255536256`*^9}, {3.542103276780115*^9, 3.5421032832837653`*^9}, {
  3.542103388313267*^9, 3.54210340594503*^9}, {3.5421034658830233`*^9, 
  3.542103515380973*^9}, {3.5421036416415977`*^9, 3.542103648361269*^9}, {
  3.54210379698213*^9, 3.542103844768908*^9}, {3.542103891419573*^9, 
  3.542103907426173*^9}, {3.542103992493679*^9, 3.542103992941724*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.542106529926367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.542106530525367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.542106530571367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Further output of \\!\\(FindRoot :: \\\"lstol\\\"\\) will \
be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.542106530613367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"cvmit\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \\!\\(100\\) iterations. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/cvmit\\\", ButtonNote -> \
\\\"FindRoot::cvmit\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.5421065356003666`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"cvmit\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \\!\\(100\\) iterations. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/cvmit\\\", ButtonNote -> \
\\\"FindRoot::cvmit\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.5421065359633665`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"cvmit\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \\!\\(100\\) iterations. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/cvmit\\\", ButtonNote -> \
\\\"FindRoot::cvmit\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.5421065363283668`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Further output of \\!\\(FindRoot :: \\\"cvmit\\\"\\) will \
be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5421039237728076`*^9, 3.5421040184692764`*^9, 
  3.542104360569483*^9, 3.542106536360367*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Fsol", "[", 
        RowBox[{"i", ",", "j"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", "resol"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "resol"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"DataRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "0.1", ",", "0.2", ",", "0.3", ",", "0.4", ",", "0.5", ",", "0.6", ",",
         "0.7", ",", "0.8", ",", "0.9"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", "Black", "}"}], "}"}]}], ",", " ", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"i", ",", "j"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.529120443921875*^9, 3.529120455421875*^9}, {
  3.52912076715625*^9, 3.529120769359375*^9}, {3.529120897109375*^9, 
  3.52912094278125*^9}, {3.542103678201253*^9, 3.542103678249258*^9}, {
  3.542103722586691*^9, 3.5421037246188946`*^9}, {3.5421040412535543`*^9, 
  3.5421040982642555`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx9mAuMVdUVhidUDfHRShCkrX2oxEYRLTa2WDWbNK22aSpQUSupYm3RttbS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    "], {{
      {GrayLevel[0.5], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmGeUkMUVhucbjNKXBIVlWYiaIrur5tgVSTmxAJYcTTwnQv7ZgI2KDcUl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          "],
          VertexColors->None], PolygonBox[CompressedData["
1:eJwtlMlLVmEYxe/7fM2TlqVmWtlcNq1s0SojrGy0webhS9Oy+qICCUMIoYII
IggXLlq4aPEtWrQMJEIi8k9oU9k8bdoEIvk7PM/i8Jxz73vfe95neGvzheYr
lmVZE5gAziAepSybAebAV4AXPH+DLsBPgQfwKVoDbwG34CtZ85HYji4Si+hl
8O2gHX0JZPCr4C28CtTBz4On8H5eL4Y3gDz6HXoL/CS4j25BfwsP8lKpf8JP
gHvwnDzBt4Jz8Mms3ygO+tGd6FL4WfAY3YX+RTyC7iH+1/nhp8FDnQP9g3gM
3UtMYBL8ILgBrwZjYKG59yH4ZXiV/KJf6czwenAc3YreBl9inpvXaCV+Npie
3KO8zgXdvH8pz/BZ5t4H0Re1FhT0LdgL/ytfyZ/tQ+8AHclzrtxvBnf5vg3d
aO5J3krAAvMcKVf6Zid8vmqkf4Em7QWeJe+BVfAL4Dl6GL3WfI3WdoJd8GZw
LXmONsD/EUuT77kfXQvKk9dctV9uXsti9E6FubcnoBX+O2rVR8yj15nnXh7k
ZbV5L8mjvNaAMvgAaDPfQ3spp+XwD/AK+E3iYfRI9G5P9MIe814d5dmfyPlg
5LgEvtv8rMqpcqsaqBaq8TTl0rxX7ugZ/Ci4Dd/E+0/xT/17TONg7lFe1TPV
8EOgKzy+jz20VyP6S+SgL3JaCf8a7zQDmoWp5rOgmdHsfI/Z0cxqdteD68lr
pFpNNO99eZTXZH52eZAX9bR6WzldZN6z6l3VcKn5jGpWtecB+Oc4a2/MTpn5
XaKZ0+zlzM+uO0N3x8+YNd05unvU8+p9zcQ8+Ezzu0YzqdlcY957ukN0l4wD
E3V6oA==
          "],
          VertexColors->None]}]}, 
      {GrayLevel[1], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmFl011cRx+/vklBBQRKgWKuFAIFiLSQQcMGQhDRQaYAQCLJlI4C2EpaC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          "],
          VertexColors->None], PolygonBox[CompressedData["
1:eJw1k+dWVUEMRu+JKPaKXekCIjYUAUVUvHYsFHv3AfSV7b0X7GXvlfHHXvNl
zZk5meRL2517k3ejVqvVoQFeVbXadjgDg2y0wRD6CvyAR9AJdehnbzOMoG/A
LzhB3Mp6EE6iN8Ie9CX4DkeJm1gvwDH0M9YeOA67ibfCKPoW/IYH0A5jsJO9
F6xbvBsGiBd7Bn0WhtB1aESfgiORd3p3NzyFJ9BlHrCLvU2wF30NfsLhyNxb
4G95k2/b73/Z+8Z63rOwhrgdhtFXYRT9puxNwjDxOhhAX4QR9AffXXKYQ9wM
g+jL/gO9AHrR43AOvQy2qeELrCDewToBM7DWN5acJswdblZZwz50ZQ/Rh+At
LCLuYz0Nn10je+Ed4+jpyNof0AfoMbiNboY/+iLyLntci3yTb7PHG8w18qxn
piJ7Zu/M4T70RtbSHM21C/ahr/vPSNR6qieyJ/bGb7qJ39mj4omI9KBe7ICH
pYbWUs+2omdF7nnGs/P0rD6Fj8XTetsedrA3W0/oHXgPjZHesWf27itMV9nT
9ZGe1tv2sEUvwRS6H1ZFekAv2LPX0GRNqvzGb2dKL5255c5KpHf1wPxIT+tt
PbA00mN6Tc92Rs6os2pPX5aczd0ZbYj0uF73TY//97zKGVoYOUPOkjV5Xmpi
bZzJuex9Kl50xpZEelAv+oaVxKsj3zpdavMP95xdng==
          "],
          VertexColors->None]}]}}, {{}, 
      {GrayLevel[0], Thickness[Large], 
       TagBox[
        TooltipBox[
         LineBox[{510, 578, 577, 595, 558, 594, 559, 596, 509, 557, 617, 556, 
          576, 554, 624, 555, 508, 553, 616, 552, 575, 550, 623, 551, 507, 
          549, 615, 548, 574, 546, 622, 547, 506, 545, 614, 544, 573, 542, 
          621, 543, 505, 541, 613, 540, 572, 538, 620, 539, 503, 535, 612, 
          534, 570, 532, 619, 533, 501, 529, 611, 528, 568, 526, 618, 527, 
          499, 592, 523, 591, 522, 566, 581, 580}],
         "0"],
        Annotation[#, 0, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         LineBox[{511, 579, 560, 586, 585, 584, 512, 590, 494, 513, 597, 480, 
          561, 481, 598, 514, 495, 515, 599, 482, 562, 483, 600, 516, 496, 
          517, 601, 484, 563, 485, 602, 518, 497, 519, 603, 486, 564, 487, 
          604, 520, 498, 521, 605, 488, 565, 489, 606, 524, 500, 525, 607, 
          490, 567, 491, 608, 530, 502, 531, 609, 492, 569, 493, 610, 536, 
          504, 593, 537, 587, 588, 589, 571, 583, 582}],
         "0"],
        Annotation[#, 0, "Tooltip"]& ]}, {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxtnXe8zvX//48osvfeK2SUkKwXMpOZUYSQERKyIyGSkbJHSlzq2NQV2euy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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[LineBox[{3012, 3238, 3013}],
         "0.9`"],
        Annotation[#, 0.9, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2978, 3221, 2979, 3229, 2994, 3228, 2995, 3237, 3010, 3236, 
          3011}],
         "0.8`"],
        Annotation[#, 0.8, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2948, 3207, 2946, 3206, 2947, 3213, 2961, 3212, 2962, 3220, 
          2977, 3219, 2975, 3218, 2976, 3227, 2992, 3226, 2993, 3235, 3008, 
          3234, 3009}],
         "0.7`"],
        Annotation[#, 0.7, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2893, 3178, 2894, 3187, 2909, 3186, 2908, 3185, 2906, 3184, 
          2907, 3193, 2921, 3192, 2919, 3191, 2920, 3199, 2932, 3198, 2933, 
          3205, 2945, 3204, 2943, 3203, 2944, 3211, 2959, 3210, 2960, 3217, 
          2974, 3216, 2972, 3215, 2973, 3225, 2990, 3224, 2991, 3233, 3006, 
          3232, 3007}],
         "0.6`"],
        Annotation[#, 0.6, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2861, 3160, 2860, 3159, 2859, 3158, 2858, 3157, 2857, 3156, 
          2855, 3155, 2856, 3167, 2872, 3166, 2871, 3165, 2869, 3164, 2870, 
          3173, 2882, 3172, 2880, 3171, 2881, 3177, 2892, 3176, 2890, 3175, 
          2891, 3183, 2905, 3182, 2903, 3181, 2904, 3190, 2917, 3189, 2918, 
          3197, 2930, 3196, 2931, 3202, 2941, 3201, 2942, 3209, 2957, 3208, 
          2958, 3214, 2971, 3223, 2988, 3222, 2989, 3231, 3000, 3230, 3005}],
         "0.5`"],
        Annotation[#, 0.5, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2822, 3138, 2821, 3137, 2820, 3136, 2819, 3135, 2818, 3134, 
          2817, 2805, 2804, 3124, 2803, 3123, 2801, 3122, 2802, 3133, 2816, 
          3132, 2815, 3131, 2814, 3130, 2813, 3129, 2811, 3128, 2812, 3143, 
          2831, 3142, 2830, 3141, 2828, 3140, 2829, 3148, 2840, 3147, 2838, 
          3146, 2839, 3151, 2846, 3150, 2847, 3154, 2853, 3153, 2854, 3163, 
          2867, 3162, 2868, 3170, 2878, 3169, 2879, 3174, 2889, 3180, 2901, 
          3179, 2902, 3188, 2916, 3195, 2928, 3194, 2929, 3200, 2940, 2952, 
          2956, 2966, 2970, 2983, 2987, 2999, 3004}],
         "0.4`"],
        Annotation[#, 0.4, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2796, 2790, 2789, 3116, 2788, 2779, 2778, 3111, 2777, 2766, 
          2765, 3106, 2764, 3105, 2763, 2752, 2751, 3100, 2750, 3099, 2749, 
          3098, 2748, 2735, 2734, 3091, 2733, 3090, 2732, 3089, 2731, 3088, 
          2730, 3087, 2728, 3086, 2729, 3097, 2747, 3096, 2746, 3095, 2745, 
          3094, 2743, 3093, 2744, 3104, 2762, 3103, 2760, 3102, 2761, 3110, 
          2776, 3109, 2774, 3108, 2775, 3115, 2786, 3114, 2787, 3119, 2794, 
          3118, 2795, 3121, 2800, 3127, 2809, 3126, 2810, 3139, 2827, 3145, 
          2836, 3144, 2837, 3149, 2845, 3152, 2852, 3161, 2866, 3168, 2877, 
          2885, 2888, 2897, 2900, 2912, 2915, 2924, 2927, 2936, 2939, 2951, 
          2955, 2965, 2969, 2982, 2986, 2998, 3003}],
         "0.3`"],
        Annotation[#, 0.3, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2782, 3112, 2780, 2769, 2767, 2755, 2753, 2738, 2736, 2724, 
          2722, 3083, 2721, 2715, 2714, 2708, 2707, 3078, 2706, 2700, 2699, 
          3074, 2698, 2692, 2691, 3070, 2690, 2684, 2683, 3066, 2682, 3065, 
          2681, 2674, 2673, 3060, 2672, 3059, 2671, 3058, 2670, 2661, 2660, 
          3051, 2659, 3050, 2658, 3049, 2657, 3048, 2656, 3047, 2654, 3046, 
          2655, 3057, 2669, 3056, 2668, 3055, 2666, 3054, 2667, 3064, 2680, 
          3063, 2678, 3062, 2679, 3069, 2688, 3068, 2689, 3073, 2696, 3072, 
          2697, 3077, 2704, 3076, 2705, 3079, 2713, 3082, 2719, 3081, 2720, 
          3085, 2727, 3092, 2742, 3101, 2759, 3107, 2773, 3113, 2785, 3117, 
          2793, 3120, 2799, 3125, 2808, 2824, 2826, 2833, 2835, 2842, 2844, 
          2849, 2851, 2863, 2865, 2874, 2876, 2884, 2887, 2896, 2899, 2911, 
          2914, 2923, 2926, 2935, 2938, 2950, 2954, 2964, 2968, 2981, 2985, 
          2997, 3002}],
         "0.2`"],
        Annotation[#, 0.2, "Tooltip"]& ]}, 
      {GrayLevel[0], 
       TagBox[
        TooltipBox[
         LineBox[{2781, 2770, 2768, 2756, 2754, 2739, 2737, 2725, 2723, 2717, 
          2716, 2710, 2709, 2702, 2701, 2694, 2693, 2686, 2685, 2676, 2675, 
          2664, 2663, 3052, 2662, 2652, 2651, 2649, 2648, 2646, 2645, 3042, 
          2644, 2641, 2640, 2638, 2637, 3038, 2636, 2633, 2632, 2629, 2628, 
          3033, 2627, 2624, 2623, 3030, 2622, 3029, 2621, 2618, 2617, 3026, 
          2616, 3025, 2615, 3024, 2614, 2609, 2608, 3019, 2607, 3018, 2606, 
          3017, 2605, 3016, 2604, 3015, 2602, 3014, 2603, 3023, 2613, 3022, 
          2612, 3021, 2610, 3020, 2611, 3028, 2619, 3027, 2620, 3032, 2625, 
          3031, 2626, 3035, 2630, 3034, 2631, 3037, 2634, 3036, 2635, 3039, 
          2639, 3041, 2642, 3040, 2643, 3043, 2647, 3044, 2650, 3045, 2653, 
          3053, 2665, 3061, 2677, 3067, 2687, 3071, 2695, 3075, 2703, 2711, 
          2712, 3080, 2718, 3084, 2726, 2740, 2741, 2757, 2758, 2771, 2772, 
          2783, 2784, 2791, 2792, 2797, 2798, 2806, 2807, 2823, 2825, 2832, 
          2834, 2841, 2843, 2848, 2850, 2862, 2864, 2873, 2875, 2883, 2886, 
          2895, 2898, 2910, 2913, 2922, 2925, 2934, 2937, 2949, 2953, 2963, 
          2967, 2980, 2984, 2996, 3001}],
         "0.1`"],
        Annotation[#, 0.1, "Tooltip"]& ]}, {}, {}}}]},
  AspectRatio->1,
  Frame->True,
  PlotRange->{{0, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5421040990223308`*^9, 3.542104374504876*^9, 
  3.5421065441783667`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"c", ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.5421062809993668`*^9, 3.542106285024367*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bandwidth (Fig 3c)", "Subsection",
 CellChangeTimes->{{3.542104816620084*^9, 3.5421048188643084`*^9}, {
   3.542104891371558*^9, 3.5421049090033207`*^9}, 3.542104954158836*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dist", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"alpha2crit0", "-", "alpha2crit1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.542106561234367*^9, 3.542106580925367*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", "c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "s"}], ")"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "s"}], ")"}], "2"]}], "-", "s"}], ")"}], 
   " ", 
   SuperscriptBox["s", "2"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "s"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
      SuperscriptBox["s", "2"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.5421065815553665`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"dist", " ", "/.", " ", 
    RowBox[{"c", "\[Rule]", "0.5"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "2"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Thick"}], "}"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5275852060105777`*^9, 3.527585252958085*^9}, {
  3.5275878331382017`*^9, 3.527587848890853*^9}, {3.5275878927739534`*^9, 
  3.5275878978312254`*^9}, {3.5284323473125*^9, 3.52843244559375*^9}, {
  3.52843261178125*^9, 3.52843261471875*^9}, {3.5284326563125*^9, 
  3.52843265678125*^9}, {3.528432695390625*^9, 3.52843273184375*^9}, {
  3.529121721625*^9, 3.529121844953125*^9}, {3.52912211828125*^9, 
  3.52912214753125*^9}, {3.529122191765625*^9, 3.529122195484375*^9}, {
  3.529122432765625*^9, 3.529122448609375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwlxQk0FIoCh3FSoYSS7CFLC0klSZq/G12yFYa4NGYsyU6k0i10DGmQJFtT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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {0, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.542105042334653*^9, 3.5421066042183666`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Range of c where polymorphism occurs (Fig3d)", "Subsection",
 CellChangeTimes->{{3.5421051090113196`*^9, 3.5421051453399525`*^9}}],

Cell["\<\
c0 = value of c where p=0 switches stability fir given da=alpha2-alpha1 and \
given s
c1= value of c where p=1 switches stability fir given da=alpha2-alpha1 and \
given s\
\>", "Text",
 CellChangeTimes->{{3.5421072613766427`*^9, 3.5421073253040347`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"c0", "=", 
  RowBox[{"c", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"u2", "/", "u1"}]}], ")"}]}], "\[Equal]", "da"}], ",", 
       "c"}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"c1", "=", 
  RowBox[{"c", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"v1", "/", "v2"}], "-", "1"}], ")"}]}], "\[Equal]", "da"}],
        ",", "c"}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.542107327603265*^9, 3.5421074158480883`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"da", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "s"}], ")"}]}], "-", 
     RowBox[{"2", " ", "s"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "s"}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "da"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]]], "Output",
 CellChangeTimes->{{3.5421073626317673`*^9, 3.542107370817586*^9}, {
  3.542107411578662*^9, 3.5421074173072343`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"da", "+", 
    RowBox[{"2", " ", "s"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "da"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]]}]], "Output",
 CellChangeTimes->{{3.5421073626317673`*^9, 3.542107370817586*^9}, {
  3.542107411578662*^9, 3.542107417312235*^9}}]
}, Open  ]],

Cell["Cut the unnecessary parts of the curves:", "Text",
 CellChangeTimes->{{3.542107659676469*^9, 3.542107668396341*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"c0mod", "[", 
    RowBox[{"ss_", ",", "dda_"}], "]"}], "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"s", "\[Rule]", "ss"}], ",", 
          RowBox[{"da", "\[Rule]", "dda"}]}], "}"}]}], ")"}], ">", 
      RowBox[{"(", 
       RowBox[{"c0", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"s", "\[Rule]", "ss"}], ",", 
          RowBox[{"da", "\[Rule]", "dda"}]}], "}"}]}], ")"}]}], ",", 
     RowBox[{"c0", " ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "\[Rule]", "ss"}], ",", 
        RowBox[{"da", "\[Rule]", "dda"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c1mod", "[", 
    RowBox[{"ss_", ",", "dda_"}], "]"}], "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"s", "\[Rule]", "ss"}], ",", 
          RowBox[{"da", "\[Rule]", "dda"}]}], "}"}]}], ")"}], ">", 
      RowBox[{"(", 
       RowBox[{"c0", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"s", "\[Rule]", "ss"}], ",", 
          RowBox[{"da", "\[Rule]", "dda"}]}], "}"}]}], ")"}]}], ",", 
     RowBox[{"c1", " ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "\[Rule]", "ss"}], ",", 
        RowBox[{"da", "\[Rule]", "dda"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.530333126688055*^9, 3.5303331784492307`*^9}, {
   3.5303332606364484`*^9, 3.530333263492734*^9}, 3.5303333141027946`*^9, {
   3.530333396714055*^9, 3.5303335244548273`*^9}, {3.5303335776091423`*^9, 
   3.530333579936375*^9}, {3.542107573641866*^9, 3.5421075997394753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c0mod", "[", 
      RowBox[{"0.2", ",", "da"}], "]"}], ",", 
     RowBox[{"c1mod", "[", 
      RowBox[{"0.2", ",", "da"}], "]"}], ",", " ", 
     RowBox[{"c0mod", "[", 
      RowBox[{"0.5", ",", "da"}], "]"}], ",", 
     RowBox[{"c1mod", "[", 
      RowBox[{"0.5", ",", "da"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"da", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Black", "}"}], ",", " ", 
      RowBox[{"{", "Black", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dashed"}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "None"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.530277203163041*^9, 3.5302772746051846`*^9}, {
  3.5303327565150414`*^9, 3.5303327944198313`*^9}, {3.530332940441432*^9, 
  3.530332960482436*^9}, {3.5303330135637436`*^9, 3.530333066974084*^9}, {
  3.5303331815465403`*^9, 3.530333187114097*^9}, {3.5303335365430365`*^9, 
  3.530333561231505*^9}, {3.5303336014255238`*^9, 3.5303336509954805`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], 
    LineBox[{{-0.3123283621037467, 
     0.14428680322355864`}, {-0.3122978700568755, 
     0.14431214930204292`}, {-0.31168802911945526`, 
     0.14481921128799036`}, {-0.31107818818203503`, 
     0.1453265408781742}, {-0.3104683472446148, 
     0.14583413828449432`}, {-0.3098585063071946, 
     0.14634200371907435`}, {-0.30924866536977436`, 
     0.14685013739426211`}, {-0.30802898349493396`, 
     0.14786721031697414`}, {-0.3073675470859337, 
     0.1484192210737967}, {-0.30670611067693343`, 
     0.1489715484032516}, {-0.30538323785893295`, 
     0.15007715386999074`}, {-0.3027374922229319, 
     0.15229217568184583`}, {-0.2974460009509299, 
     0.1567375242597265}, {-0.2868630184069258, 
     0.1656899370224435}, {-0.26569705331891763`, 
     0.18384566077239287`}, {-0.2261854619413709, 
     0.21866165659379294`}, {-0.18337176038270195`, 
     0.2578098051931686}, {-0.141337581295972, 
     0.2977681255237443}, {-0.10212374100771163`, 
     0.3364861724090348}, {-0.05960779053832902, 
     0.3801303758337309}, {-0.01991217886741602, 0.42253790472703634`}, {
     0.01900391033155799, 0.46576246322709386`}, {0.06122210971165424, 
     0.5146170688456496}, {0.10061997029328089`, 0.5621670331249174}, {
     0.14331994105602977`, 0.6159811377848341}, {0.18524038934683965`, 
     0.6712763109038739}, {0.22434049883917992`, 0.725204602311948}, {
     0.2667427185126425, 0.7864372939919136}, {0.26736118540131426`, 
     0.7873525927281306}, {0.267979652289986, 0.7882685451309887}, {
     0.26921658606732957`, 0.7901024137395526}, {0.2716904536220166, 
     0.7937780258447055}, {0.2766381887313907, 0.801160907867565}, {
     0.28653365895013894`, 0.8160545829567091}, {0.28715212583881067`, 
     0.8169911514950362}, {0.28777059272748245`, 0.8179283966210066}, {
     0.289007526504826, 0.8198049195706455}, {0.29148139405951307`, 
     0.8235661168635771}, {0.2964291291688872, 0.8311212827445211}, {
     0.2970475960575589, 0.8320687652937012}, {0.2976660629462307, 
     0.833016936293686}, {0.29890299672357423`, 0.834915346649665}, {
     0.30137686427826127`, 0.8387204618720764}, {0.3063245993876354, 
     0.8463640399740258}, {0.30693088623768316`, 0.8473037432996792}, {
     0.3075371730877309, 0.8482441198806147}, {0.3087497467878263, 
     0.8501268957045517}, {0.309356033637874, 0.851069296398259}, {
     0.3099623204879217, 0.8520123732486634}, {0.3105686073379694, 
     0.8529561269837235}, {0.31117489418801714`, 0.8539005583324419}, {
     0.31178118103806485`, 0.854845668024869}, {0.3123268392031078, 
     0.8556968473361567}}]}, 
   {GrayLevel[0], 
    LineBox[{{-0.3123283621037467, 
     0.14430077630098995`}, {-0.3122978700568755, 
     0.14434835584878966`}, {-0.31168802911945526`, 
     0.14529958589098474`}, {-0.31107818818203503`, 
     0.14625012898720452`}, {-0.3104683472446148, 
     0.1471999858813139}, {-0.3098585063071946, 
     0.14814915731610412`}, {-0.30924866536977436`, 
     0.14909764403329495`}, {-0.30802898349493396`, 
     0.15099256627640983`}, {-0.3073675470859337, 
     0.1520190451050056}, {-0.30670611067693343`, 
     0.15304472200491726`}, {-0.30538323785893295`, 
     0.15509367377475713`}, {-0.3027374922229319, 
     0.15918199540501773`}, {-0.2974460009509299, 
     0.16732051949004875`}, {-0.2868630184069258, 
     0.18344673933887698`}, {-0.26569705331891763`, 
     0.21510875103724678`}, {-0.2261854619413709, 
     0.2721920194669255}, {-0.18337176038270195`, 
     0.33124284700914786`}, {-0.141337581295972, 
     0.38657193011051816`}, {-0.10212374100771163`, 
     0.435978925831391}, {-0.05960779053832902, 
     0.4872901007130051}, {-0.01991217886741602, 0.5332084223123817}, {
     0.01900391033155799, 0.5764722618738568}, {0.06122210971165424, 
     0.6215596664427598}, {0.10061997029328089`, 0.6620002895613216}, {
     0.14331994105602977`, 0.7041515499292964}, {0.18524038934683965`, 
     0.7439308536080884}, {0.22434049883917992`, 0.7796824111898505}, {
     0.2667427185126425, 0.8170592506390939}, {0.26736118540131426`, 
     0.81759407477512}, {0.267979652289986, 0.8181286072233263}, {
     0.26921658606732957`, 0.8191967980102635}, {0.2716904536220166, 
     0.8213296898095614}, {0.2766381887313907, 0.8255815673992553}, {
     0.28653365895013894`, 0.8340301198119163}, {0.28715212583881067`, 
     0.83455572698636}, {0.28777059272748245`, 0.8350810499796584}, {
     0.289007526504826, 0.8361308443442131}, {0.29148139405951307`, 
     0.8382270330209928}, {0.2964291291688872, 0.8424058614439364}, {
     0.2970475960575589, 0.8429269492305245}, {0.2976660629462307, 
     0.8434477564928476}, {0.29890299672357423`, 0.8444885303503207}, {
     0.30137686427826127`, 0.846566721722309}, {0.3063245993876354, 
     0.8507097294967542}, {0.30693088623768316`, 0.8512161842084189}, {
     0.3075371730877309, 0.8517223727862719}, {0.3087497467878263, 
     0.8527339523791958}, {0.309356033637874, 0.8532393438130434}, {
     0.3099623204879217, 0.8537444699506325}, {0.3105686073379694, 
     0.8542493310008021}, {0.31117489418801714`, 0.8547539271721719}, {
     0.31178118103806485`, 0.8552582586731432}, {0.3123268392031078, 
     0.8557119309028943}}]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVkHs41HkUximyteSy2VZR0uiyIcql1daLh9CFQptttwvdSdlRKG0ptOop
2VoiJSVFW8qEmmr6/gyDWpcmGrnEkGHM9zslXWzWZmf/OM/7nPd5n3M+50wL
3R2wZZSWltY6Tf2v41wvNPZnM1KZssB0wXIOjvfk/iFZjCg2e0Yf8OPQ6X2c
tyydkevzc+TCVRxSmuZ/cvydET/36VcHgzh8v+1l7ZQTjMSltVU6BXNIP2of
M3CYkVw3u0l31nNYKpE9zoxghOW9GysI5zAYFJ+dsJ2RpMa66wO7OFzpnh0V
sYkRj8/B1+bzOYyM/tXc/UdGstpK75TGcij2mL5b6cnIcoH75LIkDhbc7gku
5ozwbXvm9V7kUGPitMd1IiP5c2qtLHI57N8y1LDIhJHLCaLwwKscZOOSznh+
wUiJ9fsvym5wSF19ziTgPSUmPH9+jpDDaFphFFFDyTn1XoPIBg59ppMMcg9Q
4uM//FeAXhlKwit0DV+qyEx/Xv7syDJsPOHQ33ykj3C9jbaXg8X4+3RcMoGS
BITvz9BZUI7c8e1mGZ09ZLvm+F0OFTi/1IHfcExBLF/mKcfbSXBkZ0jsbN9u
kvGgftZHy0rEjb4ew1d3kSSxTO+qfRVC4ut5svxOUqI/WBLpXI00kSLjfJic
pHq9OfoNHuN+xyz9G1btpPb5Yp+CbU8w3cjNIyi7lRQlyw9cS/oLgm+Tw7pe
vSBeU/3Eyypr0CEpsnR2lhH1zsST2/TroLBJm0dKG0iGdWy2g3c9jA8WONtp
S8nl9z/YRgY9hY3zG5u8dzUk71mGLHXkKRI81U+FsVVkMe9t1jCRwjSoMPXH
iWLyZ0h7/abEZxB8lBhW8+6T8zplmwQeDchrVZzsSywk91Y8OOxi1oh1q8yL
Wzf9QQSnPhzN72uEcFzcc/HeM8j0eZFl8eg5nLq0pxwOvgV+aLN6caEM0/sf
fHIVC6H0jb708WwTfHOba/00f9ad+/qX2JwX8FphMvpDSRV0D7/tcL/djFMb
muLt79Zg1J1j6wOFLajyszBYaSKF/c8z1ct6WqGeZnrw2bkGCHVcvmvWf4m9
e+aEnPpahtdXX1UtWdiOpjajgK3VLxDmtjS690wHNu77vldveSu8BvPNx0XJ
UT7H5Xi5bjv+6d4Yz3PsxIyxD5VXfORYyIvcEDbQCYuH4V66yZ04fTvT9au7
XdAaGlXA7+qC4xT/wNsZrzC4SrReYt2N+PamUGlMN1odN0y2TlSgc61389lY
BSLXGBlbtfWgoLZpsn9SD8z+6A7WsVBiRrT5D8tTe1H4U861d7F96B9w0oqQ
KLFm0SGfapEK0trkxpChPrR96DEUi1U4ct9yifdIH0IL/ZoeVKlg4dUyxk5H
hZ1Tp2y9JVXhU2hNzIiBJqctSkhXqJDUEDVDME2FQsnQo80GFBP6Ptqu8VVB
xy/aSXsdxa6HjoW5mSocH9M+PBRCYSU3G1+crYIh8ap4v5Xitf6hOkmuCpPs
TQOVkRQpzmOj1DdVmGtSHFmfSJGqpGtXaLjWyt7+eeEGRWj6NuuVVIWi9RFW
rsMUO8ovFW1ZrPFL+i1ytBl6MuFl6qnh0N9jNkaPIXme6GSlL0W0cL/RM2OG
loBwN7vVFK4Tkj/vmMng1OHsYbKTgoZ9OVRvw+AwNep0/S8U58tSPjjNY3A/
Jr6QEkPxeVca017EMCZGpDROoBA/vtySGaCZf8x+q+05iijLGbKRNQwTcgzz
/r5IwYspkG5ZxyCOCcyT5FEc5d2udtjOIAtcqN5cROESN7/ibIRmX8I+Z5e7
FEppKfmXz7D6yUrPL0UUyw6JSh//yrAkUKfoXjXF8HM3wdwEhuL8g8an6ygK
bSpupiUzfFpU911EI8WGBO+Cf04ypAeXf7u0hcKo5cmVkDMaXpGdYpacosze
L6cqg8HsVueOsT0U/N+kWbbZDEEDN4WUUlzTG+gd1vTy/YKGWkbxH1FODgA=

     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0H88FHYYB3BqUiSXWKW08rOkYtO1oX3SKvRDUVs/VopKKpbp90+KdFNK
K1R0U8huazYN68K+7nKvY9m4u1x+RH7ccXffr0hkLmq3P57X83q/nuf1PM/r
mRV2IHj3KCMjo22G+D+bed1+2stnpCh6c+jI6nJ4PmxdG5rByE9r/fsStpaj
zS/JcVUaI1Zf1GjyY8px+dknQ55XGVm8bvk5Oa8cPnua/55xiZH3P+4R9fDL
kZbofrTvLCNDrnzvyU/KsVKirLoZxYgwZmC/rYMIgxvi+PERjAyo354x/0yE
HNWcg1E7GakdtWPNm0AR3o8+Pd13MyOJScPOwhMiFC51OKBZxoj7qXVT+mUi
2JUfsF40nZEuP+Ey31gxqq0WHvKazEjMPJ7dzutinNitVyy2YiRVnz4lViCG
0uz8tWVjGbnc4BObqxAj5ctbVsH9lGS8vBN83+UxRtMKTlQ1JS72efNy/nkM
rY2tRfYpg1d0r1kzRYKi/RUmls06EuzxXmGSIcWOSx69Dee0pGfI8xulpBr/
fn+SR6AhL+4FpaVl1yJ7QsvUG22dpN/8mvlVJkfmSo8YxXdqUvXKSMEdU4dz
kaHH5gSoyNEoh8jXzUqcHP3T0ZjudlL3wt62kdQjNK7GUfljG5m98gjPJ6IR
qWXqG5n7WomXb6VXUF8THr2YPf6+fQvpHPBR4UIzHDhLlm7gNxFBid/uw90t
eODK29feUU/yGlyH3s1vxQtJwUwuV0ksBi2e5ja2Qu2W+jEpVpDx603XWh9s
w8QzAu58YxlJvLpHeI/TDjduj1vu62py/Legvb2Z7Yhf1l0rPCYlbhE1esv5
HbDZkJ+yebKYvKwJNzUr7sCDNxLLSsdHxP/uhM+OLFAht0mdrE3IJz5S78iU
X1TYFjS9sGnndRJyPr1k7ww1hGYn68SHr8FuRcFwKU+Nhe3GM85u+hVFHWcu
XBxUw6G3ZMhLLIRJjvjqyy2dCMhu+DtwkxjjdkU3nBd3Yvkaq9EDRVLIs8rl
/o5duLL9WZz7H9XY/5Wz2OlUF6SBdhbrrGSILo33Nq7vQvcsmzPyWwqYOMX6
F7pqcPjQ3NArHyoRUBX3O+e4Bs+ec4LDK+sxfHZrEveJBjuO+3SZrm6Cd7F5
eoCNFo/nLkp6bNKClwnBIyxMC+dxpZoc/1ZcCNDrzARa2JXuX27Ca8N6WfNY
AdXCSD9KENPejpLCBXPyPHQYDCoLkTipMHn75Y190To0eW6f5pSgBrWrlUX+
rkP0Rs5E++edUKV77Mjr02HqddWmD+w0mPfliQL1XIr8r7PyXh/TIjYnaq9L
BMXGxbH+lWU6/LHi04dSPsXzgU5LsViHTbN3dtz6gSIsP/BZiVSHOtOIwags
isiPZoT/KtMh7N8JjZPuUpwzLotPU+uwesg7KSTXMF+i/3OXBcW3l8Ju9vxM
8UHgkYXG2yhu+yxKNhJSJI1pGdaHUizY8qqx1mBLsryiP5xiZvbIxDuPKGzd
bdZroincE6f5+JYa+qwKo2sSKFwtnsbFEYotylc/375PgZBva/QSioKQKHuv
YUOf+8itFrnh3qJeuyxjhiU2HcllCgrr8YemjjFlqO3MCs98SnFEeIIjn8hQ
X1xctVlJ4WXNe7fXhaHqzpOvFA0UdJ+5vsaNgXz36lhBI0Wm6PLAwo8ZhjjW
Z680Ubz7JpUZL2bgLg39YlUzhbjqbuPNYIY3yowUUSvFwZnOyvcbGfL2OHfw
2ygcjwpku7cZ9pnIp51qp0h0/K3SI8JQT+aDq6JYdPKTivQoBuvEStdJagqN
rJiMxDDwBU7DPQavii0rrjrNYJZwMUjQRTFct+TBgngGP9/bdec1hn+7VfyS
ymPYwu1HmJZie7yf4G0yg6zjesrnOgpO4185odcYXKripbaUQuQemCW9waDY
JVG9MTjmgixjHp/B2zNEI2cUeaZ9XcMGrzB/0Pna4P8AltIedQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{3.542107611305632*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1249, 925},
WindowMargins->{{Automatic, 38}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Microsoft Windows (64-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 315, 4, 71, "Section"],
Cell[908, 29, 534, 9, 47, "Text"],
Cell[1445, 40, 1339, 44, 132, "Input"],
Cell[2787, 86, 220, 5, 65, "Text"],
Cell[3010, 93, 5555, 181, 232, "Input"],
Cell[8568, 276, 418, 13, 31, "Input"],
Cell[CellGroupData[{
Cell[9011, 293, 270, 3, 36, "Subsection"],
Cell[9284, 298, 513, 11, 31, "Input"],
Cell[9800, 311, 468, 8, 29, "Text"],
Cell[10271, 321, 983, 25, 52, "Input"],
Cell[11257, 348, 610, 17, 92, "Input"],
Cell[CellGroupData[{
Cell[11892, 369, 5344, 124, 232, "Input"],
Cell[17239, 495, 888, 15, 39, "Message"],
Cell[18130, 512, 886, 15, 39, "Message"],
Cell[19019, 529, 886, 15, 39, "Message"],
Cell[19908, 546, 697, 12, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20642, 563, 1559, 39, 92, "Input"],
Cell[22204, 604, 39249, 674, 374, "Output"]
}, Open  ]],
Cell[61468, 1281, 151, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61656, 1289, 225, 3, 36, "Subsection"],
Cell[61884, 1294, 460, 10, 31, "Input"],
Cell[62347, 1306, 468, 8, 29, "Text"],
Cell[62818, 1316, 983, 25, 52, "Input"],
Cell[63804, 1343, 610, 17, 92, "Input"],
Cell[CellGroupData[{
Cell[64439, 1364, 5146, 121, 232, "Input"],
Cell[69588, 1487, 721, 13, 39, "Message"],
Cell[70312, 1502, 721, 13, 39, "Message"],
Cell[71036, 1517, 721, 13, 39, "Message"],
Cell[71760, 1532, 530, 10, 21, "Message"],
Cell[72293, 1544, 531, 10, 21, "Message"],
Cell[72827, 1556, 531, 10, 21, "Message"],
Cell[73361, 1568, 531, 10, 21, "Message"],
Cell[73895, 1580, 530, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74462, 1595, 1559, 39, 92, "Input"],
Cell[76024, 1636, 37745, 651, 374, "Output"]
}, Open  ]],
Cell[113784, 2290, 149, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113970, 2298, 182, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[114177, 2304, 197, 4, 31, "Input"],
Cell[114377, 2310, 1058, 37, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115472, 2352, 989, 21, 31, "Input"],
Cell[116464, 2375, 3255, 58, 253, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[119768, 2439, 136, 1, 36, "Subsection"],
Cell[119907, 2442, 264, 6, 47, "Text"],
Cell[CellGroupData[{
Cell[120196, 2452, 881, 27, 52, "Input"],
Cell[121080, 2481, 615, 21, 47, "Output"],
Cell[121698, 2504, 392, 12, 47, "Output"]
}, Open  ]],
Cell[122105, 2519, 122, 1, 29, "Text"],
Cell[122230, 2522, 1877, 54, 52, "Input"],
Cell[CellGroupData[{
Cell[124132, 2580, 1399, 35, 52, "Input"],
Cell[125534, 2617, 9719, 169, 251, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
